.. pypol documentation master file, created by
   sphinx-quickstart on Thu Aug 26 17:23:17 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pypol v0.5 documentation!
====================================

:Author: Michele Lacchia (michelelacchia@gmail.com)
:Release: |release|
:Date: |today|

pypol is a Python library that allows you to manipulate polynomials. This is the main page of the documentation.


Installation
------------

pypol is on `PyPI <http://pypi.python.org/pypi/pypol_/0.5>`_ too. If you have setuptools installed, you can use `easy_install <http://peak.telecommunity.com/DevCenter/EasyInstall>`_::

    $ easy_install -U pypol_

and **don't forget the underscore!** Because if you try::

    $ easy_install -U pypol

**you will install a different package!**

.. seealso::
    :ref:`install`

Contents
--------

.. toctree::
   :maxdepth: 4
   :numbered:
   
   tutorial.rst
   functions.rst
   classes.rst
   operations.rst
   funcs.rst
   roots.rst
   series.rst
   contacts.rst
   changelog.rst